@@ -32,7 +32,7 @@ import (
 	"github.com/emirpasic/gods/sets/treeset"
 	godsutils "github.com/emirpasic/gods/utils"
 
-	"github.com/bazelbuild/rules_python/gazelle/pythonconfig"
+	"github.com/bazel-contrib/rules_python/gazelle/pythonconfig"
 )
 
 const (
